import { dataSource } from "../../../data-source";
import { mission_contact } from "../../../entity/operation/mission_contact";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { DeleteMissionContactCommand, SyncMissionContactCommand } from "./missionContactCommand";

export default abstract class MissionContactCommandHandler {
  /**
   * @description update mission_contact
   * @param {Array<SyncMissionCommand>} updateMissionContact
   * @returns {Promise<void>}
   */
  static async sync(updateMissionContact: Array<SyncMissionContactCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(mission_contact)
      .values(updateMissionContact)
      .orUpdate(["firstname", "lastname", "phone", "address", "note"], ["missionId", "contactId"])
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "mission_contact", err);
      });
  }

  /**
   * @description delete mission_contact
   * @param {Array<DeleteMissionCommand>} deleteMissionContact
   * @returns {Promise<void>}
   */
  static async delete(deleteMissionContact: Array<DeleteMissionContactCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(mission_contact)
      .whereInIds(deleteMissionContact)
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "mission_contact", err);
      });
  }
}
