import { dataSource } from "../../../data-source";
import { mission_equipment } from "../../../entity/operation/mission_equipment";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { DeleteMissionEquipmentCommand, SyncMissionEquipmentCommand } from "./missionEquipmentCommand";

export default abstract class MissionEquipmentCommandHandler {
  /**
   * @description update mission_equipment
   * @param {Array<SyncMissionCommand>} updateMissionEquipment
   * @returns {Promise<void>}
   */
  static async sync(updateMissionEquipment: Array<SyncMissionEquipmentCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(mission_equipment)
      .values(updateMissionEquipment)
      .orUpdate(["note"], ["missionId", "equipmentId"])
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "mission_equipment", err);
      });
  }

  /**
   * @description delete mission_equipment
   * @param {Array<DeleteMissionCommand>} deleteMissionEquipment
   * @returns {Promise<void>}
   */
  static async delete(deleteMissionEquipment: Array<DeleteMissionEquipmentCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(mission_equipment)
      .whereInIds(deleteMissionEquipment)
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "mission_equipment", err);
      });
  }
}
