import { dataSource } from "../../../data-source";
import { mission_presence } from "../../../entity/operation/mission_presence";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { DeleteMissionPresenceCommand, SyncMissionPresenceCommand } from "./missionPresenceCommand";

export default abstract class MissionPresenceCommandHandler {
  /**
   * @description update mission-presence
   * @param {Array<SyncMissionCommand>} updateMissionpresence
   * @returns {Promise<void>}
   */
  static async sync(updateMissionpresence: Array<SyncMissionPresenceCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(mission_presence)
      .values(updateMissionpresence)
      .orIgnore()
      // .orUpdate([], ["missionId", "forceId"])
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "mission-presence", err);
      });
  }

  /**
   * @description delete mission-presence
   * @param {Array<DeleteMissionCommand>} deleteMissionpresence
   * @returns {Promise<void>}
   */
  static async delete(deleteMissionpresence: Array<DeleteMissionPresenceCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(mission_presence)
      .whereInIds(deleteMissionpresence)
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "mission-presence", err);
      });
  }
}
