import { dataSource } from "../../../data-source";
import { mission_vehicle } from "../../../entity/operation/mission_vehicle";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { DeleteMissionVehicleCommand, SyncMissionVehicleCommand } from "./missionVehicleCommand";

export default abstract class MissionVehicleCommandHandler {
  /**
   * @description update mission_vehicle
   * @param {Array<SyncMissionCommand>} updateMissionVehicle
   * @returns {Promise<void>}
   */
  static async sync(updateMissionVehicle: Array<SyncMissionVehicleCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(mission_vehicle)
      .values(updateMissionVehicle)
      .orUpdate(["driverId", "leaderId", "mileage_start", "mileage_end"], ["missionId", "vehicleId"])
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "mission_vehicle", err);
      });
  }

  /**
   * @description delete mission_vehicle
   * @param {Array<DeleteMissionCommand>} deleteMissionVehicle
   * @returns {Promise<void>}
   */
  static async delete(deleteMissionVehicle: Array<DeleteMissionVehicleCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(mission_vehicle)
      .whereInIds(deleteMissionVehicle)
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "mission_vehicle", err);
      });
  }
}
