import { Column, ColumnType, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryColumn } from "typeorm";
import { force } from "../configuration/force";
import { mission_presence } from "./mission_presence";
import { mission_vehicle } from "./mission_vehicle";
import { mission_equipment } from "./mission_equipment";
import { mission_contact } from "./mission_contact";
import { getTypeByORM } from "../../migrations/ormHelper";

@Entity()
export class mission {
  @PrimaryColumn({ generated: "uuid" })
  id: string;

  @Column({ type: "varchar", length: 255, default: "" })
  title: string;

  @Column({ type: "varchar", length: 36, nullable: true })
  commandId?: string | null;

  @Column({ type: "varchar", length: 36, nullable: true })
  secretaryId?: string | null;

  @Column({ type: getTypeByORM("datetime").type as ColumnType, nullable: true, default: null })
  mission_start?: Date | null;

  @Column({ type: getTypeByORM("datetime").type as ColumnType, nullable: true, default: null })
  mission_end?: Date | null;

  @Column({ type: "varchar", length: 255, default: "" })
  keyword: string;

  @Column({ type: "varchar", length: 255, default: "" })
  location: string;

  @Column({ type: "varchar", length: 255, default: "" })
  others: string;

  @Column({ type: "int", default: 0 })
  rescued: number;

  @Column({ type: "int", default: 0 })
  recovered: number;

  @Column({ type: "text", default: "[]" })
  description: string;

  @Column({ type: "bigint", default: 0 })
  last_update: number;

  @CreateDateColumn()
  createdAt: Date;

  @ManyToOne(() => force, {
    onDelete: "RESTRICT",
    onUpdate: "RESTRICT",
  })
  command: force;

  @ManyToOne(() => force, {
    onDelete: "RESTRICT",
    onUpdate: "RESTRICT",
  })
  secretary: force;

  @OneToMany(() => mission_presence, (mf) => mf.mission, { cascade: ["insert"] })
  presence: mission_presence[];

  @OneToMany(() => mission_vehicle, (mv) => mv.mission, { cascade: ["insert"] })
  vehicles: mission_vehicle[];

  @OneToMany(() => mission_equipment, (me) => me.mission, { cascade: ["insert"] })
  equipments: mission_equipment[];

  @OneToMany(() => mission_contact, (mc) => mc.mission, { cascade: ["insert"] })
  contacts: mission_contact[];
}
