import { equipment } from "../../../entity/configuration/equipment";
import { EquipmentViewModel } from "../../../viewmodel/admin/configuration/equipment.models";

export default abstract class EquipmentFactory {
  /**
   * @description map record to equipment
   * @param {equipment} record
   * @returns {EquipmentViewModel}
   */
  public static mapToSingle(record: equipment): EquipmentViewModel {
    return {
      id: record.id,
      code: record.code,
      type: record.type,
      name: record.name,
      commissioned: record.commissioned,
      decommissioned: record.decommissioned,
    };
  }

  /**
   * @description map records to equipment
   * @param {Array<equipment>} records
   * @returns {Array<EquipmentViewModel>}
   */
  public static mapToBase(records: Array<equipment>): Array<EquipmentViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
