import { vehicle } from "../../../entity/configuration/vehicle";
import { VehicleViewModel } from "../../../viewmodel/admin/configuration/vehicle.models";

export default abstract class VehicleFactory {
  /**
   * @description map record to vehicle
   * @param {vehicle} record
   * @returns {VehicleViewModel}
   */
  public static mapToSingle(record: vehicle): VehicleViewModel {
    return {
      id: record.id,
      code: record.code,
      type: record.type,
      name: record.name,
      commissioned: record.commissioned,
      decommissioned: record.decommissioned,
    };
  }

  /**
   * @description map records to vehicle
   * @param {Array<vehicle>} records
   * @returns {Array<VehicleViewModel>}
   */
  public static mapToBase(records: Array<vehicle>): Array<VehicleViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
