import { Table, TableForeignKey } from "typeorm";
import { getDefaultByORM, getTypeByORM, isUUIDPrimary } from "../ormHelper";

export const mission_table = new Table({
  name: "mission",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "title", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "commandId", ...getTypeByORM("uuid", true), default: getDefaultByORM("null") },
    { name: "secretaryId", ...getTypeByORM("uuid", true), default: getDefaultByORM("null") },
    { name: "mission_start", ...getTypeByORM("datetime", true, 6), default: getDefaultByORM("null") },
    { name: "mission_end", ...getTypeByORM("datetime", true, 6), default: getDefaultByORM("null") },
    { name: "keyword", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "location", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "others", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "rescued", ...getTypeByORM("int"), default: getDefaultByORM("number", 0) },
    { name: "recovered", ...getTypeByORM("int"), default: getDefaultByORM("number", 0) },
    { name: "description", ...getTypeByORM("text"), default: getDefaultByORM("string", "[]") },
    { name: "last_update", ...getTypeByORM("bigint"), default: getDefaultByORM("number", 0) },
    { name: "createdAt", ...getTypeByORM("datetime", false, 6), default: getDefaultByORM("currentTimestamp") },
  ],
});

export const mission_presence_table = new Table({
  name: "mission_presence",
  columns: [
    { name: "missionId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "forceId", ...getTypeByORM("uuid"), isPrimary: true },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["missionId"],
      referencedColumnNames: ["id"],
      referencedTableName: "mission",
      onDelete: "CASCADE",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["forceId"],
      referencedColumnNames: ["id"],
      referencedTableName: "force",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const mission_vehicle_table = new Table({
  name: "mission_vehicle",
  columns: [
    { name: "missionId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "vehicleId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "driverId", ...getTypeByORM("uuid", true), default: getDefaultByORM("null") },
    { name: "leaderId", ...getTypeByORM("uuid", true), default: getDefaultByORM("null") },
    { name: "mileage_start", ...getTypeByORM("int", true), default: getDefaultByORM("null") },
    { name: "mileage_end", ...getTypeByORM("int", true), default: getDefaultByORM("null") },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["missionId"],
      referencedColumnNames: ["id"],
      referencedTableName: "mission",
      onDelete: "CASCADE",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["vehicleId"],
      referencedColumnNames: ["id"],
      referencedTableName: "vehicle",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["driverId"],
      referencedColumnNames: ["id"],
      referencedTableName: "force",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["leaderId"],
      referencedColumnNames: ["id"],
      referencedTableName: "force",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const mission_equipment_table = new Table({
  name: "mission_equipment",
  columns: [
    { name: "missionId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "equipmentId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "note", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["missionId"],
      referencedColumnNames: ["id"],
      referencedTableName: "mission",
      onDelete: "CASCADE",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["equipmentId"],
      referencedColumnNames: ["id"],
      referencedTableName: "equipment",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const mission_contact_table = new Table({
  name: "mission_contact",
  columns: [
    { name: "missionId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "contactId", ...getTypeByORM("uuid"), isPrimary: true },
    { name: "firstname", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "lastname", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "phone", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "address", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
    { name: "note", ...getTypeByORM("varchar"), default: getDefaultByORM("string") },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["missionId"],
      referencedColumnNames: ["id"],
      referencedTableName: "mission",
      onDelete: "CASCADE",
      onUpdate: "RESTRICT",
    }),
  ],
});
