import express, { Request, Response } from "express";
import {
  createEquipment,
  decommissionEquipmentById,
  deleteEquipmentById,
  getAllEquipments,
  getAvailabeEquipmentsByMission,
  getEquipmentById,
  getEquipmentsByIds,
  updateEquipmentById,
} from "../../../controller/admin/configuration/equipmentController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllEquipments(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getEquipmentsByIds(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getEquipmentById(req, res);
});

router.get("/available/:missionId", async (req: Request, res: Response) => {
  await getAvailabeEquipmentsByMission(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "operation", "equipment"),
  async (req: Request, res: Response) => {
    await createEquipment(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "operation", "equipment"),
  async (req: Request, res: Response) => {
    await updateEquipmentById(req, res);
  }
);

router.patch(
  "/:id/decommission",
  PermissionHelper.passCheckMiddleware("update", "operation", "equipment"),
  async (req: Request, res: Response) => {
    await decommissionEquipmentById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "operation", "equipment"),
  async (req: Request, res: Response) => {
    await deleteEquipmentById(req, res);
  }
);

export default router;
