import express, { Request, Response } from "express";
import {
  createForce,
  decommissionForceById,
  deleteForceById,
  getAllForces,
  getForceById,
  getForcesByIds,
  getAvailabeForcesByMission,
  updateForceById,
} from "../../../controller/admin/configuration/forceController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllForces(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getForcesByIds(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getForceById(req, res);
});

router.get("/available/:missionId", async (req: Request, res: Response) => {
  await getAvailabeForcesByMission(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "operation", "force"),
  async (req: Request, res: Response) => {
    await createForce(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "operation", "force"),
  async (req: Request, res: Response) => {
    await updateForceById(req, res);
  }
);

router.patch(
  "/:id/decommission",
  PermissionHelper.passCheckMiddleware("update", "operation", "force"),
  async (req: Request, res: Response) => {
    await decommissionForceById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "operation", "force"),
  async (req: Request, res: Response) => {
    await deleteForceById(req, res);
  }
);

export default router;
