import express from "express";
import PermissionHelper from "../../helpers/permissionHelper";

import mission from "./operation/mission";

import equipment from "./configuration/equipment";
import force from "./configuration/force";
import vehicle from "./configuration/vehicle";

import role from "./management/role";
import user from "./management/user";
import invite from "./management/invite";
import backup from "./management/backup";

var router = express.Router({ mergeParams: true });

router.use("/mission", PermissionHelper.passCheckMiddleware("read", "operation", "mission"), mission);

router.use(
  "/equipment",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "configuration", module: "equipment" },
    { requiredPermissions: "read", section: "operation", module: "mission" },
  ]),
  equipment
);
router.use(
  "/force",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "configuration", module: "force" },
    { requiredPermissions: "read", section: "operation", module: "mission" },
  ]),
  force
);
router.use(
  "/vehicle",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "configuration", module: "vehicle" },
    { requiredPermissions: "read", section: "operation", module: "mission" },
  ]),
  vehicle
);

router.use("/role", PermissionHelper.passCheckMiddleware("read", "management", "role"), role);
router.use(
  "/user",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "management", module: "user" },
    { requiredPermissions: "read", section: "management", module: "role" },
  ]),
  user
);
router.use("/invite", PermissionHelper.passCheckMiddleware("read", "management", "user"), invite);
router.use("/backup", PermissionHelper.passCheckMiddleware("read", "management", "backup"), backup);

export default router;
