import express, { Request, Response } from "express";
import {
  createMission,
  deleteMissionById,
  getAllMissions,
  getMissionById,
} from "../../../controller/admin/operation/missionController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllMissions(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getMissionById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "operation", "mission"),
  async (req: Request, res: Response) => {
    await createMission(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "operation", "mission"),
  async (req: Request, res: Response) => {
    await deleteMissionById(req, res);
  }
);

export default router;
