import { Server, Socket } from "socket.io";
import { SocketMap } from "../../storage/socketMap";
import CustomRequestException from "../../exceptions/customRequestException";
import { MissionMap } from "../../storage/missionMap";

export default (io: Server, socket: Socket) => {
  socket.on("ping", (callback: Function) => {
    callback();
  });

  socket.on("error", (err) => {
    let status = 500;
    let msg = "Internal Server Error";

    if (err instanceof CustomRequestException) {
      status = err.statusCode;
      msg = err.message;
    }

    if (err instanceof CustomRequestException) {
      console.log("WS Custom Handler", status, msg);
    } else {
      console.log("WS Error Handler", err);
    }

    socket.emit("error", msg);
    socket.leave("home");
  });

  socket.on("disconnecting", () => {
    console.log("socket disconnection: ", socket.id);
    const socketRooms = Array.from(socket.rooms).filter((room) => room !== socket.id && room !== "home");
    if (socketRooms[0]) {
      socket.leave(socketRooms[0]);
      MissionMap.updateAwareness(socketRooms[0], {
        action: "remove",
        store: "editors",
        update: undefined,
        socketId: socket.id,
      });
      io.to(socketRooms[0]).emit("package-sync-awareness", {
        type: "editors",
        update: undefined,
        action: "remove",
        socketId: socket.id,
      });

      MissionMap.updateAwareness(socketRooms[0], {
        action: "remove",
        store: "state",
        update: undefined,
        socketId: socket.id,
      });
      io.to(socketRooms[0]).emit("package-sync-awareness", {
        type: "state",
        update: undefined,
        action: "remove",
        socketId: socket.id,
      });

      const clients = io.sockets.adapter.rooms.get(socketRooms[0]);
      if (!clients || clients.size == 0) {
        MissionMap.delete(socketRooms[0]);
      }
    }

    SocketMap.delete(socket.id);
  });

  socket.on("disconnect", () => {});
};
