import helmet from "helmet";
import { Server as httpServerType } from "http";
import { Server } from "socket.io";
import authenticateSocket from "./middleware/authenticateSocket";
import base from "./endpoints/base";
import perRequestCheck from "./middleware/perRequestCheck";
import missionManagement from "./endpoints/missionManagement";
import { instrument } from "@socket.io/admin-ui";

export default abstract class SocketServer {
  private static io: Server;

  public static init(httpServer: httpServerType) {
    this.io = new Server(httpServer, {
      cors: {
        origin: "*",
        methods: ["GET", "POST"],
        credentials: true,
      },
    });
    if (process.env.NODE_ENV) {
      instrument(this.io, {
        auth: false,
        mode: "development",
      });
    }

    this.io.engine.use(helmet());

    this.io
      .of("/")
      .use(authenticateSocket)
      .on("connection", (socket) => {
        console.log("socket connection: ", socket.id);
        socket.use((packet, next) => authenticateSocket(socket, next));
        socket.use((packet, next) => perRequestCheck(socket, packet, next));

        base(this.io, socket);
        missionManagement(this.io, socket);
      });
  }

  public static broadcastNewMission(id: string) {
    this.io.emit("created-new-mission", id);
  }
}
